// ------------------------------------------------------------------------------------
// <copyright file="TiposDocumentoBL.cs" company="Universidad Distrital">
// Copyright (c) Universidad Distrital. All rights reserved.
// </copyright>
// <author>Camilo Prieto</author>
// ------------------------------------------------------------------------------------
namespace Biblioteca.Negocio.Clases.BL
{
	using System;
	using System.Collections.Generic;
	using System.Threading.Tasks;
	using Biblioteca.Datos.Clases.DAL.Repositorio;
	using Biblioteca.IC.Acciones.Repositorio;
	using Biblioteca.IC.DTO.Repositorio;
	using Biblioteca.IC.Recursos;
	using TransaccionalNet.EF.Clases;
	using UtilitariosNet.Clases.Comunes.Entidades;
	using Utilitarios.TransversalesNet.Clases.Comunes.Enumeraciones;

	/// <summary>
	/// Clase con las acciones de negocio de la entidad TiposDocumento
	/// </summary>
	public class TiposDocumentoBL : AccesoComunBL, ITiposDocumentoNegocioAccion
	{

		#region ATRIBUTOS
		/// <summary>
		/// Objeto para repositorio TiposDocumento
		/// <summary>
		/// Objeto para acciones TiposDocumento
		/// </summary>
		private Lazy<ITiposDocumentoRepositorioAccion> tiposDocumentoRepositorioAccion;

		/// <summary>
		/// Objeto para entidad respuesta
		/// </summary>
		Respuesta<ITiposDocumentoDTO> respuesta;

		#endregion ATRIBUTOS
		#region CONSTRUCTORES
		/// <summary>
		/// Inicializa una nueva instancia de la clase TiposDocumentoBL
		/// </summary>
		/// <param name="argTiposDocumentoRepositorioAccion">Acciones entidad TiposDocumento</param>
		public TiposDocumentoBL(Lazy<ITiposDocumentoRepositorioAccion> argTiposDocumentoRepositorioAccion = null)
		{
			this.respuesta = new Respuesta<ITiposDocumentoDTO>();
			this.tiposDocumentoRepositorioAccion = argTiposDocumentoRepositorioAccion ?? new Lazy<ITiposDocumentoRepositorioAccion>(() => new TiposDocumentoDAL());
		}

		#endregion CONSTRUCTORES
		#region METODOS PUBLICOS
		/// <summary>
		/// Metodo consultar lista tiposDocumento
		/// </summary>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		public async Task<Respuesta<ITiposDocumentoDTO>> ConsultarListaTiposDocumentoAsync()
		{

			return await this.EjecutarTransaccionBDAsync<Respuesta<ITiposDocumentoDTO>, TiposDocumentoBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.tiposDocumentoRepositorioAccion.Value.ConsultarListaTiposDocumentoAsync();
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 return respuesta;

			});

		}
		/// <summary>
		/// Metodo consultar por llave tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a consultar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		public async Task<Respuesta<ITiposDocumentoDTO>> ConsultarTiposDocumentoLlaveAsync(ITiposDocumentoDTO tiposDocumento)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<ITiposDocumentoDTO>, TiposDocumentoBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.tiposDocumentoRepositorioAccion.Value.ConsultarTiposDocumentoLlaveAsync(tiposDocumento);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 return respuesta;

			});
		}

		/// <summary>
		/// Metodo editar tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a editar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		public async Task<Respuesta<ITiposDocumentoDTO>> EditarTiposDocumentoAsync(ITiposDocumentoDTO tiposDocumento)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<ITiposDocumentoDTO>, TiposDocumentoBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.tiposDocumentoRepositorioAccion.Value.EditarTiposDocumentoAsync(tiposDocumento);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeCreacionEdicionExitosa);
				 return respuesta;

			});
		}


		/// <summary>
		/// Metodo eliminar tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a eliminar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		public async Task<Respuesta<ITiposDocumentoDTO>> EliminarTiposDocumentoAsync(ITiposDocumentoDTO tiposDocumento)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<ITiposDocumentoDTO>, TiposDocumentoBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.tiposDocumentoRepositorioAccion.Value.EliminarTiposDocumentoAsync(tiposDocumento);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeEntidadEliminadaConExito);
				 return respuesta;

			});
		}

		/// <summary>
		/// Metodo guardar tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a guardar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		public async Task<Respuesta<ITiposDocumentoDTO>> GuardarTiposDocumentoAsync(ITiposDocumentoDTO tiposDocumento)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<ITiposDocumentoDTO>, TiposDocumentoBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.tiposDocumentoRepositorioAccion.Value.GuardarTiposDocumentoAsync(tiposDocumento);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeCreacionEdicionExitosa);
				 return respuesta;

			});
		}

		/// <summary>
		/// Metodo Guardar lista tiposDocumento
		/// </summary>
		/// <param name="listaTiposDocumento">Lista de entidades a guardar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		public async Task<Respuesta<ITiposDocumentoDTO>> GuardarListaTiposDocumentoAsync(List<ITiposDocumentoDTO> listaTiposDocumento)
		{
			return await this.EjecutarTransaccionBDAsync<Respuesta<ITiposDocumentoDTO>, TiposDocumentoBL>(
			System.Transactions.IsolationLevel.ReadUncommitted,
			async () =>
			{
				 respuesta= await this.tiposDocumentoRepositorioAccion.Value.GuardarListaTiposDocumentoAsync(listaTiposDocumento);
				 respuesta.Resultado = true;
				 respuesta.TipoNotificacion = TipoNotificacion.Exitoso;
				 respuesta.Mensajes.Add(rcsMensajesComunes.MensajeCreacionEdicionExitosa);
				 return respuesta;

			});
		}
		#endregion METODOS PUBLICOS
		#region METODOS PRIVADOS
		#endregion METODOS PRIVADOS
	}
}

