// ------------------------------------------------------------------------------------
// <copyright file="TiposDocumentoController.cs" company="Universidad Distrital">
// Copyright (c) Universidad Distrital. All rights reserved.
// </copyright>
// <author>Camilo Prieto</author>
// ------------------------------------------------------------------------------------
namespace Biblioteca.API.Controllers
{
	using System;
	using System.Collections.Generic;
	using System.Threading.Tasks;
	using Utilitarios.APINet.Clases.Ejecucion;
	using UtilitariosNet.Clases.Comunes.Entidades;
	using UtilitariosNet.Clases.Mapeador.Extensiones;
	using Biblioteca.API.Models.Repositorio;
	using Biblioteca.IC.Acciones.Repositorio;
	using Biblioteca.Negocio.Clases.BL;
	using Microsoft.AspNetCore.Mvc;
	
	/// <summary>
	/// Clase con las capaciades Rest de la entidad TiposDocumento
	/// </summary>
	[Route("api/TiposDocumento")]
	public class TiposDocumentoController : AccesoComunAPI
	{


		/// <summary>
		/// Objeto para negocio TiposDocumento
		/// </summary>
		private Lazy<ITiposDocumentoNegocioAccion> negocioTiposDocumento;

		
		/// <summary>
		/// Inicializa una nueva instancia de la clase TiposDocumentoController
		/// </summary>
		public TiposDocumentoController()
		{
			this.negocioTiposDocumento = new Lazy<ITiposDocumentoNegocioAccion>(
										() => new TiposDocumentoBL());
		}
		
		/// <summary>
		/// Metodo consultar lista tiposDocumento
		/// </summary>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		[HttpGet]
		[Route("ConsultarListaTiposDocumento")]
		public async Task<Respuesta<TiposDocumento>> ConsultarListaTiposDocumento()
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<TiposDocumento>>, TiposDocumentoController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<TiposDocumento>>(await negocioTiposDocumento.Value.ConsultarListaTiposDocumentoAsync());
			});
		}
		
		/// <summary>
		/// Metodo consultar por llave tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a consultar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		[HttpPost]
		[Route("ConsultarTiposDocumentoLlave")]
		public async Task<Respuesta<TiposDocumento>> ConsultarTiposDocumentoLlave(TiposDocumento tiposDocumento)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<TiposDocumento>>, TiposDocumentoController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<TiposDocumento>>(await negocioTiposDocumento.Value.ConsultarTiposDocumentoLlaveAsync(tiposDocumento));
			});
		}
		
		/// <summary>
		/// Metodo guardar tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a guardar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		[HttpPost]
		[Route("GuardarTiposDocumento")]
		public async Task<Respuesta<TiposDocumento>> GuardarTiposDocumento(TiposDocumento tiposDocumento)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<TiposDocumento>>, TiposDocumentoController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<TiposDocumento>>(await negocioTiposDocumento.Value.GuardarTiposDocumentoAsync(tiposDocumento));
			});
		}
		
		/// <summary>
		/// Metodo editar tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a editar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		[HttpPut]
		[Route("EditarTiposDocumento")]
		public async Task<Respuesta<TiposDocumento>> EditarTiposDocumento(TiposDocumento tiposDocumento)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<TiposDocumento>>, TiposDocumentoController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<TiposDocumento>>(await negocioTiposDocumento.Value.EditarTiposDocumentoAsync(tiposDocumento));
			});
		}
		
		/// <summary>
		/// Metodo eliminar tiposDocumento
		/// </summary>
		/// <param name="tiposDocumento">Entidad a eliminar</param>
		/// <returns>Respuesta tipo TiposDocumento </returns>
		[HttpDelete]
		[Route("EliminarTiposDocumento")]
		public async Task<Respuesta<TiposDocumento>> EliminarTiposDocumento(TiposDocumento tiposDocumento)
		{
			return await this.EjecutarTransaccionAPI<Task<Respuesta<TiposDocumento>>, TiposDocumentoController>(async () =>
			{
				return Mapeador.MapearObjetoPorJson<Respuesta<TiposDocumento>>(await negocioTiposDocumento.Value.EliminarTiposDocumentoAsync(tiposDocumento));
			});
		}
	}
}

